package SyForm::Class;
BEGIN {
  $SyForm::Class::AUTHORITY = 'cpan:GETTY';
}
# ABSTRACT: TODO
$SyForm::Class::VERSION = '0.008';
use Moose;
use namespace::clean -except => 'meta';

# TODO

1;

__END__

=pod

=head1 NAME

SyForm::Class - TODO

=head1 VERSION

version 0.008

=head1 AUTHOR

Torsten Raudssus <torsten@raudss.us>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Torsten Raudssus.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
